package initializer
import "k8s.io/apiserver/pkg/admission/plugin/webhook/initializer"
Index ¶
- type PluginInitializer
- func NewPluginInitializer( authenticationInfoResolverWrapper webhook.AuthenticationInfoResolverWrapper, serviceResolver webhook.ServiceResolver, ) *PluginInitializer
- func (i *PluginInitializer) Initialize(plugin admission.Interface)
- type ServiceResolver
- type WantsAuthenticationInfoResolverWrapper
- type WantsServiceResolver
Types ¶
type PluginInitializer ¶
type PluginInitializer struct {
// contains filtered or unexported fields
}
PluginInitializer is used for initialization of the webhook admission plugin.
func NewPluginInitializer ¶
func NewPluginInitializer( authenticationInfoResolverWrapper webhook.AuthenticationInfoResolverWrapper, serviceResolver webhook.ServiceResolver, ) *PluginInitializer
NewPluginInitializer constructs new instance of PluginInitializer
func (*PluginInitializer) Initialize ¶
func (i *PluginInitializer) Initialize(plugin admission.Interface)
Initialize checks the initialization interfaces implemented by each plugin and provide the appropriate initialization data
type ServiceResolver ¶
type ServiceResolver interface {
ResolveEndpoint(namespace, name string, port int32) (*url.URL, error)
}
ServiceResolver knows how to convert a service reference into an actual location.
type WantsAuthenticationInfoResolverWrapper ¶
type WantsAuthenticationInfoResolverWrapper interface {
SetAuthenticationInfoResolverWrapper(wrapper webhook.AuthenticationInfoResolverWrapper)
admission.InitializationValidator
}
WantsAuthenticationInfoResolverWrapper defines a function that wraps the standard AuthenticationInfoResolver to allow the apiserver to control what is returned as auth info
type WantsServiceResolver ¶
type WantsServiceResolver interface {
SetServiceResolver(webhook.ServiceResolver)
}
WantsServiceResolver defines a function that accepts a ServiceResolver for admission plugins that need to make calls to services.
Source Files ¶
initializer.go
- Version
- v0.36.0 (latest)
- Published
- Apr 22, 2026
- Platform
- linux/amd64
- Imports
- 3 packages
- Last checked
- 4 days ago –
Tools for package owners.