apiserverk8s.io/apiserver/pkg/server/flagz/negotiate Index | Files

package negotiate

import "k8s.io/apiserver/pkg/server/flagz/negotiate"

Index

Types

type FlagzEndpointRestrictions

type FlagzEndpointRestrictions struct {
	RecognizedStructuredKinds map[schema.GroupVersionKind]bool
}

FlagzEndpointRestrictions implements content negotiation restrictions for the flagz endpoint. It is used to validate and restrict which GroupVersionKinds are allowed for structured responses.

func (FlagzEndpointRestrictions) AllowsMediaTypeTransform

func (f FlagzEndpointRestrictions) AllowsMediaTypeTransform(mimeType string, mimeSubType string, gvk *schema.GroupVersionKind) bool

AllowsMediaTypeTransform checks if the provided GVK is supported for structured flagz responses.

func (FlagzEndpointRestrictions) AllowsServerVersion

func (FlagzEndpointRestrictions) AllowsServerVersion(string) bool

func (FlagzEndpointRestrictions) AllowsStreamSchema

func (FlagzEndpointRestrictions) AllowsStreamSchema(s string) bool

Source Files

negotiation.go

Version
v0.36.0 (latest)
Published
Apr 22, 2026
Platform
linux/amd64
Imports
1 packages
Last checked
5 days ago

Tools for package owners.