apiserverk8s.io/apiserver/pkg/server/statusz/api/v1beta1 Index | Files

package v1beta1

import "k8s.io/apiserver/pkg/server/statusz/api/v1beta1"

Package v1beta1 contains API Schema definitions for the statusz v1beta1 API group

Index

Constants

const (
	GroupName = "config.k8s.io"
	Version   = "v1beta1"
)

Variables

var (
	// SchemeBuilder initializes a scheme builder
	SchemeBuilder = runtime.NewSchemeBuilder(addKnownTypes)
	// AddToScheme is a global function that adds this group's types to a scheme
	AddToScheme = SchemeBuilder.AddToScheme
)
var SchemeGroupVersion = schema.GroupVersion{Group: GroupName, Version: Version}

SchemeGroupVersion is group version used to register these objects

Types

type Statusz

type Statusz struct {
	// TypeMeta is the type metadata for the object.
	metav1.TypeMeta `json:",inline"`
	// Standard object's metadata.
	// +optional
	metav1.ObjectMeta `json:"metadata,omitempty"`
	// StartTime is the time the component process was initiated.
	StartTime metav1.Time `json:"startTime"`
	// UptimeSeconds is the duration in seconds for which the component has been running continuously.
	UptimeSeconds int64 `json:"uptimeSeconds"`
	// GoVersion is the version of the Go programming language used to build the binary.
	// The format is not guaranteed to be consistent across different Go builds.
	// +optional
	GoVersion string `json:"goVersion"`
	// BinaryVersion is the version of the component's binary.
	// The format is not guaranteed to be semantic versioning and may be an arbitrary string.
	BinaryVersion string `json:"binaryVersion"`
	// EmulationVersion is the Kubernetes API version which this component is emulating.
	// if present, formatted as "<major>.<minor>"
	// +optional
	EmulationVersion string `json:"emulationVersion,omitempty"`
	// Paths contains relative URLs to other essential read-only endpoints for debugging and troubleshooting.
	// +optional
	// +listType=set
	Paths []string `json:"paths"`
}

+k8s:deepcopy-gen:interfaces=k8s.io/apimachinery/pkg/runtime.Object Statusz is a struct used for versioned statusz endpoint.

func (*Statusz) DeepCopy

func (in *Statusz) DeepCopy() *Statusz

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Statusz.

func (*Statusz) DeepCopyInto

func (in *Statusz) DeepCopyInto(out *Statusz)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*Statusz) DeepCopyObject

func (in *Statusz) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

func (Statusz) OpenAPIModelName

func (in Statusz) OpenAPIModelName() string

OpenAPIModelName returns the OpenAPI model name for this type.

Source Files

doc.go register.go types.go zz_generated.deepcopy.go zz_generated.model_name.go

Version
v0.36.0 (latest)
Published
Apr 22, 2026
Platform
linux/amd64
Imports
3 packages
Last checked
5 days ago

Tools for package owners.