package feature
import "k8s.io/apiserver/pkg/storage/feature"
Index ¶
Types ¶
type FeatureSupportChecker ¶
type FeatureSupportChecker interface {
// Supports check if the feature is supported or not by checking internal cache.
// By default all calls to this function before calling CheckClient returns false.
// Returns true if all endpoints in etcd clients are supporting the feature.
// If client A supports and client B doesn't support the feature, the `Supports` will
// first return true at client A initializtion and then return false on client B
// initialzation, it can flip the support at runtime.
Supports(feature storage.Feature) bool
// CheckClient works with etcd client to recalcualte feature support and cache it internally.
// All etcd clients should support feature to cause `Supports` return true.
// If client A supports and client B doesn't support the feature, the `Supports` will
// first return true at client A initializtion and then return false on client B
// initialzation, it can flip the support at runtime.
CheckClient(ctx context.Context, c client, feature storage.Feature)
}
FeatureSupportChecker to define Supports functions.
var ( // DefaultFeatureSupportChecker is a shared global etcd FeatureSupportChecker. DefaultFeatureSupportChecker FeatureSupportChecker = newDefaultFeatureSupportChecker() )
Source Files ¶
feature_support_checker.go
- Version
- v0.36.0 (latest)
- Published
- Apr 22, 2026
- Platform
- linux/amd64
- Imports
- 11 packages
- Last checked
- 4 days ago –
Tools for package owners.