package storagebackend
import "k8s.io/apiserver/pkg/storage/storagebackend"
Index ¶
- Constants
- type Config
- func NewDefaultConfig(prefix string, codec runtime.Codec) *Config
- func (config *Config) ForResource(resource schema.GroupResource) *ConfigForResource
- type ConfigForResource
- type TransportConfig
Constants ¶
const ( StorageTypeUnset = "" StorageTypeETCD2 = "etcd2" StorageTypeETCD3 = "etcd3" DefaultCompactInterval = 5 * time.Minute DefaultDBMetricPollInterval = 30 * time.Second DefaultEventsHistoryWindow = 75 * time.Second DefaultHealthcheckTimeout = 2 * time.Second DefaultReadinessTimeout = 2 * time.Second )
Types ¶
type Config ¶
type Config struct {
// Type defines the type of storage backend. Default ("") is "etcd3".
Type string
// Prefix is the prefix to all keys passed to storage.Interface methods.
Prefix string
// Transport holds all connection related info, i.e. equal TransportConfig means equal servers we talk to.
Transport TransportConfig
Codec runtime.Codec
// EncodeVersioner is the same groupVersioner used to build the
// storage encoder. Given a list of kinds the input object might belong
// to, the EncodeVersioner outputs the gvk the object will be
// converted to before persisted in etcd.
EncodeVersioner runtime.GroupVersioner
// Transformer allows the value to be transformed prior to persisting into etcd.
Transformer value.Transformer
// CompactionInterval is an interval of requesting compaction from apiserver.
// If the value is 0, no compaction will be issued.
CompactionInterval time.Duration
// CountMetricPollPeriod specifies how often should count metric be updated
CountMetricPollPeriod time.Duration
// DBMetricPollInterval specifies how often should storage backend metric be updated.
DBMetricPollInterval time.Duration
// EventsHistoryWindow specifies minimum history duration that storage is keeping.
EventsHistoryWindow time.Duration
// HealthcheckTimeout specifies the timeout used when checking health
HealthcheckTimeout time.Duration
// ReadycheckTimeout specifies the timeout used when checking readiness
ReadycheckTimeout time.Duration
LeaseManagerConfig etcd3.LeaseManagerConfig
// StorageObjectCountTracker is used to keep track of the total
// number of objects in the storage per resource.
StorageObjectCountTracker flowcontrolrequest.StorageObjectCountTracker
}
Config is configuration for creating a storage backend.
func NewDefaultConfig ¶
func (*Config) ForResource ¶
func (config *Config) ForResource(resource schema.GroupResource) *ConfigForResource
ForResource specializes to the given resource
type ConfigForResource ¶
type ConfigForResource struct {
// Config is the resource-independent configuration
Config
// GroupResource is the relevant one
GroupResource schema.GroupResource
}
ConfigForResource is a Config specialized to a particular `schema.GroupResource`
type TransportConfig ¶
type TransportConfig struct {
// ServerList is the list of storage servers to connect with.
ServerList []string
// TLS credentials
KeyFile string
CertFile string
TrustedCAFile string
// function to determine the egress dialer. (i.e. konnectivity server dialer)
EgressLookup egressselector.Lookup
// The TracerProvider can add tracing the connection
TracerProvider oteltrace.TracerProvider
}
TransportConfig holds all connection related info, i.e. equal TransportConfig means equal servers we talk to.
Source Files ¶
config.go
Directories ¶
| Path | Synopsis |
|---|---|
| pkg/storage/storagebackend/factory |
- Version
- v0.36.0 (latest)
- Published
- Apr 22, 2026
- Platform
- linux/amd64
- Imports
- 9 packages
- Last checked
- 4 days ago –
Tools for package owners.