apiserverk8s.io/apiserver/pkg/util/peerproxy/metrics Index | Files

package metrics

import "k8s.io/apiserver/pkg/util/peerproxy/metrics"

Index

Constants

const (

	// ProxyErrorEndpointResolution indicates a failure to resolve the network address of a peer apiserver.
	ProxyErrorEndpointResolution = "endpoint_resolution"
	// ProxyErrorTransport indicates a failure to build the proxy transport for the request.
	ProxyErrorTransport = "proxy_transport"

	// DiscoveryErrorLeaseList indicates a failure to list apiserver identity leases.
	DiscoveryErrorLeaseList = "lease_list"
	// DiscoveryErrorHostPortResolution indicates a failure to resolve host/port from an identity lease.
	DiscoveryErrorHostPortResolution = "hostport_resolution"
	// DiscoveryErrorFetch indicates a failure to fetch discovery document from a peer.
	DiscoveryErrorFetch = "fetch_discovery"
)

Functions

func IncPeerDiscoverySyncError

func IncPeerDiscoverySyncError(ctx context.Context, e string)

IncPeerDiscoverySyncError increments the # of errors encountered during peer discovery sync

func IncPeerProxiedRequest

func IncPeerProxiedRequest(ctx context.Context, status, g, v, r string)

IncPeerProxiedRequest increments the # of proxied requests to peer kube-apiserver

func IncPeerProxyError

func IncPeerProxyError(ctx context.Context, e, g, v, r string)

IncPeerProxyError increments the # of errors encountered during peer proxying

func Register

func Register()

func Reset

func Reset()

Only used for tests.

Source Files

metrics.go

Version
v0.36.0 (latest)
Published
Apr 22, 2026
Platform
linux/amd64
Imports
4 packages
Last checked
4 days ago

Tools for package owners.